## Array `.flatten()` method

Arrays now have a `.flatten()` method, which turns nested arrays into a single
flat array. This provides the same effect that Meson often does to arrays
internally, such as when passed to most function arguments.
